==> libtorrent_0.12.0.orig.tar.gz: libtorrent-0.12.0/src/tracker/tracker_dht.h <==
// libTorrent - BitTorrent library
// Copyright (C) 2005-2007, Jari Sundell
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// In addition, as a special exception, the copyright holders give
// permission to link the code of portions of this program with the
// OpenSSL library under certain conditions as described in each
// individual source file, and distribute linked combinations
// including the two.
//
// You must obey the GNU General Public License in all respects for
// all of the code used other than OpenSSL.  If you modify file(s)
// with this exception, you may extend this exception to your version
// of the file(s), but you are not obligated to do so.  If you do not
// wish to do so, delete this exception statement from your version.
// If you delete this exception statement from all source files in the
// program, then also delete it here.
//
// Contact:  Jari Sundell <jaris@ifi.uio.no>
//
//           Skomakerveien 33
//           3185 Skoppum, NORWAY

#ifndef LIBTORRENT_TRACKER_TRACKER_DHT_H
#define LIBTORRENT_TRACKER_TRACKER_DHT_H

#include "net/address_list.h"
#include "torrent/object.h"
#include "torrent/tracker.h"

namespace torrent {

class TrackerDht : public Tracker {
public:
  TrackerDht(TrackerList* parent, const std::string& url);
  ~TrackerDht();

  typedef enum {
    state_idle,
    state_searching,
    state_announcing,
  } state_type;

  static const char* states[];
  
  virtual bool        is_busy() const;
  virtual bool        is_usable() const;

  virtual void        send_state(int state);
  virtual void        close();

  virtual Type        type() const;

  virtual void        get_status(char* buffer, int length);

  void                set_state(state_type state)      { m_state = state; }
  state_type          get_state() const                { return m_state; }

  bool                has_peers() const                { return !m_peers.empty(); }

  void                receive_peers(const std::string& peers);
  void                receive_success();
  void                receive_failed(const char* msg);
  void                receive_progress(int replied, int contacted);

private:
  AddressList  m_peers;
  state_type   m_state;

  int          m_replied;
  int          m_contacted;
};

}

#endif

==> libtorrent-0.12.6.tar.gz: libtorrent-0.12.6/src/tracker/tracker_dht.h <==
// libTorrent - BitTorrent library
// Copyright (C) 2005-2007, Jari Sundell
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// In addition, as a special exception, the copyright holders give
// permission to link the code of portions of this program with the
// OpenSSL library under certain conditions as described in each
// individual source file, and distribute linked combinations
// including the two.
//
// You must obey the GNU General Public License in all respects for
// all of the code used other than OpenSSL.  If you modify file(s)
// with this exception, you may extend this exception to your version
// of the file(s), but you are not obligated to do so.  If you do not
// wish to do so, delete this exception statement from your version.
// If you delete this exception statement from all source files in the
// program, then also delete it here.
//
// Contact:  Jari Sundell <jaris@ifi.uio.no>
//
//           Skomakerveien 33
//           3185 Skoppum, NORWAY

#ifndef LIBTORRENT_TRACKER_TRACKER_DHT_H
#define LIBTORRENT_TRACKER_TRACKER_DHT_H

#include "net/address_list.h"
#include "torrent/object.h"
#include "torrent/tracker.h"

namespace torrent {

class TrackerDht : public Tracker {
public:
  TrackerDht(TrackerList* parent, const std::string& url);
  ~TrackerDht();

  typedef enum {
    state_idle,
    state_searching,
    state_announcing,
  } state_type;

  static const char* states[];
  
  virtual bool        is_busy() const;
  virtual bool        is_usable() const;

  virtual void        send_state(int state);
  virtual void        close();

  virtual Type        type() const;

  virtual void        get_status(char* buffer, int length);

  void                set_state(state_type state)      { m_state = state; }
  state_type          get_state() const                { return m_state; }

  bool                has_peers() const                { return !m_peers.empty(); }

  void                receive_peers(const Object& peer_list);
  void                receive_success();
  void                receive_failed(const char* msg);
  void                receive_progress(int replied, int contacted);

private:
  AddressList  m_peers;
  state_type   m_state;

  int          m_replied;
  int          m_contacted;
};

}

#endif
